@@ -1,9 +1,9 @@
 package ExtUtils::InstallPaths;
 {
-  $ExtUtils::InstallPaths::VERSION = '0.009';
+  $ExtUtils::InstallPaths::VERSION = '0.010';
 }
 
-use 5.006;
+use 5.008001;
 use strict;
 use warnings;
 
@@ -102,47 +102,22 @@ sub new {
 	return bless \%self, $class;
 }
 
+my @install_sets_keys = qw/lib arch bin script bindoc libdoc binhtml libhtml/;
+my @install_sets_tail = qw/bin script man1dir man3dir html1dir html3dir/;
+my %install_sets_values = (
+	core   => [ qw/privlib archlib /, @install_sets_tail ],
+	site   => [ map { "site$_" } qw/lib arch/, @install_sets_tail ],
+	vendor => [ map { "vendor$_" } qw/lib arch/, @install_sets_tail ],
+);
+
 sub _default_install_sets {
 	my $c = shift;
 
-	my $bindoc  = $c->get('installman1dir');
-	my $libdoc  = $c->get('installman3dir');
-
-	my $binhtml = $c->get('installhtml1dir') || $c->get('installhtmldir');
-	my $libhtml = $c->get('installhtml3dir') || $c->get('installhtmldir');
-
-	return {
-		core   => {
-			lib     => $c->get('installprivlib'),
-			arch    => $c->get('installarchlib'),
-			bin     => $c->get('installbin'),
-			script  => $c->get('installscript'),
-			bindoc  => $bindoc,
-			libdoc  => $libdoc,
-			binhtml => $binhtml,
-			libhtml => $libhtml,
-		},
-		site   => {
-			lib     => $c->get('installsitelib'),
-			arch    => $c->get('installsitearch'),
-			bin     => $c->get('installsitebin') || $c->get('installbin'),
-			script  => $c->get('installsitescript') || $c->get('installsitebin') || $c->get('installscript'),
-			bindoc  => $c->get('installsiteman1dir') || $bindoc,
-			libdoc  => $c->get('installsiteman3dir') || $libdoc,
-			binhtml => $c->get('installsitehtml1dir') || $binhtml,
-			libhtml => $c->get('installsitehtml3dir') || $libhtml,
-		},
-		vendor => {
-			lib     => $c->get('installvendorlib'),
-			arch    => $c->get('installvendorarch'),
-			bin     => $c->get('installvendorbin') || $c->get('installbin'),
-			script  => $c->get('installvendorscript') || $c->get('installvendorbin') || $c->get('installscript'),
-			bindoc  => $c->get('installvendorman1dir') || $bindoc,
-			libdoc  => $c->get('installvendorman3dir') || $libdoc,
-			binhtml => $c->get('installvendorhtml1dir') || $binhtml,
-			libhtml => $c->get('installvendorhtml3dir') || $libhtml,
-		},
-	};
+	my %ret;
+	for my $installdir (qw/core site vendor/) {
+		@{$ret{$installdir}}{@install_sets_keys} = map { $c->get("install$_") } @{ $install_sets_values{$installdir} };
+	}
+	return \%ret;
 }
 
 sub _default_base_relpaths {
@@ -159,6 +134,15 @@ sub _default_base_relpaths {
 	};
 }
 
+my %common_prefix_relpaths = (
+	bin        => ['bin'],
+	script     => ['bin'],
+	bindoc     => ['man', 'man1'],
+	libdoc     => ['man', 'man3'],
+	binhtml    => ['html'],
+	libhtml    => ['html'],
+);
+
 sub _default_prefix_relpaths {
 	my $c = shift;
 
@@ -170,32 +154,17 @@ sub _default_prefix_relpaths {
 		core => {
 			lib        => [@libstyle],
 			arch       => [@libstyle, $version, $arch],
-			bin        => ['bin'],
-			script     => ['bin'],
-			bindoc     => ['man', 'man1'],
-			libdoc     => ['man', 'man3'],
-			binhtml    => ['html'],
-			libhtml    => ['html'],
+			%common_prefix_relpaths,
 		},
 		vendor => {
 			lib        => [@libstyle],
 			arch       => [@libstyle, $version, $arch],
-			bin        => ['bin'],
-			script     => ['bin'],
-			bindoc     => ['man', 'man1'],
-			libdoc     => ['man', 'man3'],
-			binhtml    => ['html'],
-			libhtml    => ['html'],
+			%common_prefix_relpaths,
 		},
 		site => {
 			lib        => [@libstyle, 'site_perl'],
 			arch       => [@libstyle, 'site_perl', $version, $arch],
-			bin        => ['bin'],
-			script     => ['bin'],
-			bindoc     => ['man', 'man1'],
-			libdoc     => ['man', 'man3'],
-			binhtml    => ['html'],
-			libhtml    => ['html'],
+			%common_prefix_relpaths,
 		},
 	};
 }
@@ -204,11 +173,10 @@ sub _default_original_prefix {
 	my $c = shift;
 
 	my %ret = (
-		core   => $c->get('installprefixexp') || $c->get('installprefix') || $c->get('prefixexp') || $c->get('prefix') || '',
+		core   => $c->get('installprefixexp'),
 		site   => $c->get('siteprefixexp'),
 		vendor => $c->get('usevendorprefix') ? $c->get('vendorprefixexp') : '',
 	);
-	$ret{site} ||= $ret{core};
 
 	return \%ret;
 }
@@ -230,8 +198,6 @@ sub is_default_installable {
 	return $installable ? 1 : 0;
 }
 
-#Carp::croak('Value must be a relative path') if File::Spec::Unix->file_name_is_absolute($value);
-
 sub _prefixify_default {
 	my $self = shift;
 	my $type = shift;
@@ -429,8 +395,8 @@ sub install_map {
 
 # ABSTRACT: Build.PL install path logic made easy
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -439,7 +405,7 @@ ExtUtils::InstallPaths - Build.PL install path logic made easy
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
@@ -662,4 +628,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
